@@ -1,6 +1,8 @@
 import sys
 import os
 
+from tfkit.utility import tok_sep
+
 dir_path = os.path.dirname(os.path.realpath(__file__))
 sys.path.append(os.path.abspath(os.path.join(dir_path, os.pardir)))
 
@@ -40,7 +42,7 @@ class BertOneByOne(nn.Module):
         type_tensors = torch.tensor(types).to(self.device)
         mask_tensors = torch.tensor(masks).to(self.device)
 
-        outputs = self.pretrained(tokens_tensor,  attention_mask=mask_tensors)
+        outputs = self.pretrained(tokens_tensor, attention_mask=mask_tensors)
         sequence_output = outputs[0]
         prediction_scores = self.model(sequence_output)
         outputs = (prediction_scores,)
@@ -60,14 +62,11 @@ class BertOneByOne(nn.Module):
 
     def predict(self, input, task=None):
         self.eval()
-        predicted = 0
         with torch.no_grad():
             output = ""
-            outputs = []
             output_prob_dict = []
             while True:
                 feature_dict = get_feature_from_data(self.tokenizer, self.maxlen, input, output)
-                # print(feature_dict)
                 if len(feature_dict['input']) > self.maxlen:
                     break
                 start = feature_dict['start']
@@ -76,13 +75,15 @@ class BertOneByOne(nn.Module):
                 predictions = self.forward(feature_dict, eval=True)
                 predictions = predictions[0][0]
                 logit_prob = softmax(predictions[start]).data.tolist()
-                prob_result = {self.tokenizer.ids_to_tokens[id]: prob for id, prob in enumerate(logit_prob)}
-                prob_result = sorted(prob_result.items(), key=lambda x: x[1], reverse=True)
+                prob_result = {self.tokenizer.decode([id]): prob for id, prob in enumerate(logit_prob)}
+                prob_result = sorted(prob_result.items(), key=lambda x: x[1], reverse=True)[:3]
                 output_prob_dict.append(prob_result)
                 predicted_index = torch.argmax(predictions[start]).item()
                 predicted_token = self.tokenizer.convert_ids_to_tokens([predicted_index])
                 if predicted_token[0] != "#":
                     predicted_token[0] = predicted_token[0].replace("#", "")
+                if tok_sep(self.tokenizer) in predicted_token:
+                    break
                 output += predicted_token[0] + ' '
 
             return output, output_prob_dict
@@ -106,7 +107,7 @@ class BertOneByOne(nn.Module):
             if not filteredOne:
                 break
 
-    def predict_beamsearch(self, input, topk=3, filtersim=False):
+    def predict_beamsearch(self, input, topk=3, filtersim=True, task=None):
         self.eval()
         sequences = [[[], 1.0]]
         with torch.no_grad():
@@ -127,7 +128,7 @@ class BertOneByOne(nn.Module):
                         predictions = predictions[0][0]
                         predictions = predictions[feature_dict['start']][0]
                         logit_prob = softmax(predictions).data.tolist()
-                        prob_result = {self.tokenizer.ids_to_tokens[id]: prob for id, prob in enumerate(logit_prob)}
+                        prob_result = {self.tokenizer.decode([id]): prob for id, prob in enumerate(logit_prob)}
 
                         for k, v in sorted(prob_result.items(), key=lambda x: x[1], reverse=True)[:50]:
                             if k != "#":
