@@ -132,9 +132,8 @@ def get_feature_from_data(tokenizer, labels, input, target=None, maxlen=512, sep
     mapping_index = []
 
     pos = 1  # cls as start 0
-    basic_len = len(tokenizer.tokenize("hi")) - 1
     for i in input:
-        for _ in range(len(tokenizer.tokenize(i)) - basic_len):
+        for _ in range(len([x for x in tokenizer.tokenize(i) if x not in tokenizer.all_special_tokens or x == tokenizer.unk_token])):
             if _ < 1:
                 mapping_index.append({'char': i, 'pos': pos})
             pos += 1
@@ -144,12 +143,12 @@ def get_feature_from_data(tokenizer, labels, input, target=None, maxlen=512, sep
         target_token = []
 
         for i, t in zip(input, target):
-            for _ in range(len(tokenizer.tokenize(i))-basic_len):
+            for _ in range(len([x for x in tokenizer.tokenize(i) if x not in tokenizer.all_special_tokens or x == tokenizer.unk_token])):
                 target_token += [labels.index(t)]
 
         target_id = [labels.index("O")] + target_token + [labels.index("O")]
         if len(input_id) != len(target_id):
-            print("input target len not equal", len(input), len(target), input, target, input_id, target_id)
+            print("input target len not equal", len(input_id), len(target_id), len(input), len(target))
         target_id.extend([0] * (maxlen - len(target_id)))
         row_dict['target'] = np.asarray(target_id)
 
