@@ -103,16 +103,18 @@ def main():
         eval_dataset = loadOneByOneDataset(arg.valid[0], pretrained=arg.config, maxlen=arg.maxlen, cache=arg.cache)
         model = BertOneByOne(model_config=arg.config, maxlen=arg.maxlen)
     elif 'classify' in arg.model:
-        train_dataset = loadClassifierDataset(arg.train[0], pretrained=arg.config)
-        eval_dataset = loadClassifierDataset(arg.valid[0], pretrained=arg.config)
+        train_dataset = loadClassifierDataset(arg.train[0], pretrained=arg.config, cache=arg.cache)
+        eval_dataset = loadClassifierDataset(arg.valid[0], pretrained=arg.config, cache=arg.cache)
         model = BertMtClassifier(train_dataset.task, arg.config)
     elif 'tag' in arg.model:
         if "row" in arg.model:
-            train_dataset = loadRowTaggerDataset(arg.train[0], pretrained=arg.config, maxlen=arg.maxlen)
-            eval_dataset = loadRowTaggerDataset(arg.valid[0], pretrained=arg.config, maxlen=arg.maxlen)
+            train_dataset = loadRowTaggerDataset(arg.train[0], pretrained=arg.config, maxlen=arg.maxlen,
+                                                 cache=arg.cache)
+            eval_dataset = loadRowTaggerDataset(arg.valid[0], pretrained=arg.config, maxlen=arg.maxlen, cache=arg.cache)
         elif "col" in arg.model:
-            train_dataset = loadColTaggerDataset(arg.train[0], pretrained=arg.config, maxlen=arg.maxlen)
-            eval_dataset = loadColTaggerDataset(arg.valid[0], pretrained=arg.config, maxlen=arg.maxlen)
+            train_dataset = loadColTaggerDataset(arg.train[0], pretrained=arg.config, maxlen=arg.maxlen,
+                                                 cache=arg.cache)
+            eval_dataset = loadColTaggerDataset(arg.valid[0], pretrained=arg.config, maxlen=arg.maxlen, cache=arg.cache)
         model = BertTagger(train_dataset.label, arg.config, maxlen=arg.maxlen)
 
     train_iter = data.DataLoader(dataset=train_dataset,
